Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/org.eclipse.etrice.core.config/src-gen/org/eclipse/etrice/core/config/impl/DynamicConfigImpl.java')
-rw-r--r--plugins/org.eclipse.etrice.core.config/src-gen/org/eclipse/etrice/core/config/impl/DynamicConfigImpl.java132
1 files changed, 94 insertions, 38 deletions
diff --git a/plugins/org.eclipse.etrice.core.config/src-gen/org/eclipse/etrice/core/config/impl/DynamicConfigImpl.java b/plugins/org.eclipse.etrice.core.config/src-gen/org/eclipse/etrice/core/config/impl/DynamicConfigImpl.java
index 97bfa5d09..5cad00a9d 100644
--- a/plugins/org.eclipse.etrice.core.config/src-gen/org/eclipse/etrice/core/config/impl/DynamicConfigImpl.java
+++ b/plugins/org.eclipse.etrice.core.config/src-gen/org/eclipse/etrice/core/config/impl/DynamicConfigImpl.java
@@ -23,8 +23,9 @@ import org.eclipse.etrice.core.config.DynamicConfig;
* <p>
* The following features are implemented:
* <ul>
- * <li>{@link org.eclipse.etrice.core.config.impl.DynamicConfigImpl#getSource <em>Source</em>}</li>
* <li>{@link org.eclipse.etrice.core.config.impl.DynamicConfigImpl#getFilePath <em>File Path</em>}</li>
+ * <li>{@link org.eclipse.etrice.core.config.impl.DynamicConfigImpl#getUserCode1 <em>User Code1</em>}</li>
+ * <li>{@link org.eclipse.etrice.core.config.impl.DynamicConfigImpl#getUserCode2 <em>User Code2</em>}</li>
* <li>{@link org.eclipse.etrice.core.config.impl.DynamicConfigImpl#getPolling <em>Polling</em>}</li>
* </ul>
* </p>
@@ -34,44 +35,64 @@ import org.eclipse.etrice.core.config.DynamicConfig;
public class DynamicConfigImpl extends MinimalEObjectImpl.Container implements DynamicConfig
{
/**
- * The default value of the '{@link #getSource() <em>Source</em>}' attribute.
+ * The default value of the '{@link #getFilePath() <em>File Path</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @see #getSource()
+ * @see #getFilePath()
* @generated
* @ordered
*/
- protected static final String SOURCE_EDEFAULT = null;
+ protected static final String FILE_PATH_EDEFAULT = null;
/**
- * The cached value of the '{@link #getSource() <em>Source</em>}' attribute.
+ * The cached value of the '{@link #getFilePath() <em>File Path</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @see #getSource()
+ * @see #getFilePath()
* @generated
* @ordered
*/
- protected String source = SOURCE_EDEFAULT;
+ protected String filePath = FILE_PATH_EDEFAULT;
/**
* The default value of the '{@link #getFilePath() <em>File Path</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @see #getFilePath()
+ * @see #getUserCode1()
* @generated
* @ordered
*/
- protected static final String FILE_PATH_EDEFAULT = null;
+ protected static final String USER_CODE1_EDEFAULT = null;
/**
* The cached value of the '{@link #getFilePath() <em>File Path</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @see #getFilePath()
+ * @see #getUserCode1()
* @generated
* @ordered
*/
- protected String filePath = FILE_PATH_EDEFAULT;
+ protected String userCode1 = USER_CODE1_EDEFAULT;
+
+ /**
+ * The default value of the '{@link #getUserCode2() <em>User Code2</em>}' attribute.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @see #getUserCode2()
+ * @generated
+ * @ordered
+ */
+ protected static final String USER_CODE2_EDEFAULT = null;
+
+ /**
+ * The cached value of the '{@link #getUserCode2() <em>User Code2</em>}' attribute.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @see #getUserCode2()
+ * @generated
+ * @ordered
+ */
+ protected String userCode2 = USER_CODE2_EDEFAULT;
/**
* The default value of the '{@link #getPolling() <em>Polling</em>}' attribute.
@@ -119,9 +140,9 @@ public class DynamicConfigImpl extends MinimalEObjectImpl.Container implements D
* <!-- end-user-doc -->
* @generated
*/
- public String getSource()
+ public String getFilePath()
{
- return source;
+ return filePath;
}
/**
@@ -129,12 +150,12 @@ public class DynamicConfigImpl extends MinimalEObjectImpl.Container implements D
* <!-- end-user-doc -->
* @generated
*/
- public void setSource(String newSource)
+ public void setFilePath(String newFilePath)
{
- String oldSource = source;
- source = newSource;
+ String oldFilePath = filePath;
+ filePath = newFilePath;
if (eNotificationRequired())
- eNotify(new ENotificationImpl(this, Notification.SET, ConfigPackage.DYNAMIC_CONFIG__SOURCE, oldSource, source));
+ eNotify(new ENotificationImpl(this, Notification.SET, ConfigPackage.DYNAMIC_CONFIG__FILE_PATH, oldFilePath, filePath));
}
/**
@@ -142,9 +163,9 @@ public class DynamicConfigImpl extends MinimalEObjectImpl.Container implements D
* <!-- end-user-doc -->
* @generated
*/
- public String getFilePath()
+ public String getUserCode1()
{
- return filePath;
+ return userCode1;
}
/**
@@ -152,12 +173,35 @@ public class DynamicConfigImpl extends MinimalEObjectImpl.Container implements D
* <!-- end-user-doc -->
* @generated
*/
- public void setFilePath(String newFilePath)
+ public void setUserCode1(String newUserCode1)
{
- String oldFilePath = filePath;
- filePath = newFilePath;
+ String oldUserCode1 = userCode1;
+ userCode1 = newUserCode1;
if (eNotificationRequired())
- eNotify(new ENotificationImpl(this, Notification.SET, ConfigPackage.DYNAMIC_CONFIG__FILE_PATH, oldFilePath, filePath));
+ eNotify(new ENotificationImpl(this, Notification.SET, ConfigPackage.DYNAMIC_CONFIG__USER_CODE1, oldUserCode1, userCode1));
+ }
+
+ /**
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
+ public String getUserCode2()
+ {
+ return userCode2;
+ }
+
+ /**
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
+ public void setUserCode2(String newUserCode2)
+ {
+ String oldUserCode2 = userCode2;
+ userCode2 = newUserCode2;
+ if (eNotificationRequired())
+ eNotify(new ENotificationImpl(this, Notification.SET, ConfigPackage.DYNAMIC_CONFIG__USER_CODE2, oldUserCode2, userCode2));
}
/**
@@ -193,10 +237,12 @@ public class DynamicConfigImpl extends MinimalEObjectImpl.Container implements D
{
switch (featureID)
{
- case ConfigPackage.DYNAMIC_CONFIG__SOURCE:
- return getSource();
case ConfigPackage.DYNAMIC_CONFIG__FILE_PATH:
return getFilePath();
+ case ConfigPackage.DYNAMIC_CONFIG__USER_CODE1:
+ return getUserCode1();
+ case ConfigPackage.DYNAMIC_CONFIG__USER_CODE2:
+ return getUserCode2();
case ConfigPackage.DYNAMIC_CONFIG__POLLING:
return getPolling();
}
@@ -213,12 +259,15 @@ public class DynamicConfigImpl extends MinimalEObjectImpl.Container implements D
{
switch (featureID)
{
- case ConfigPackage.DYNAMIC_CONFIG__SOURCE:
- setSource((String)newValue);
- return;
case ConfigPackage.DYNAMIC_CONFIG__FILE_PATH:
setFilePath((String)newValue);
return;
+ case ConfigPackage.DYNAMIC_CONFIG__USER_CODE1:
+ setUserCode1((String)newValue);
+ return;
+ case ConfigPackage.DYNAMIC_CONFIG__USER_CODE2:
+ setUserCode2((String)newValue);
+ return;
case ConfigPackage.DYNAMIC_CONFIG__POLLING:
setPolling((Integer)newValue);
return;
@@ -236,12 +285,15 @@ public class DynamicConfigImpl extends MinimalEObjectImpl.Container implements D
{
switch (featureID)
{
- case ConfigPackage.DYNAMIC_CONFIG__SOURCE:
- setSource(SOURCE_EDEFAULT);
- return;
case ConfigPackage.DYNAMIC_CONFIG__FILE_PATH:
setFilePath(FILE_PATH_EDEFAULT);
return;
+ case ConfigPackage.DYNAMIC_CONFIG__USER_CODE1:
+ setUserCode1(USER_CODE1_EDEFAULT);
+ return;
+ case ConfigPackage.DYNAMIC_CONFIG__USER_CODE2:
+ setUserCode2(USER_CODE2_EDEFAULT);
+ return;
case ConfigPackage.DYNAMIC_CONFIG__POLLING:
setPolling(POLLING_EDEFAULT);
return;
@@ -259,10 +311,12 @@ public class DynamicConfigImpl extends MinimalEObjectImpl.Container implements D
{
switch (featureID)
{
- case ConfigPackage.DYNAMIC_CONFIG__SOURCE:
- return SOURCE_EDEFAULT == null ? source != null : !SOURCE_EDEFAULT.equals(source);
case ConfigPackage.DYNAMIC_CONFIG__FILE_PATH:
return FILE_PATH_EDEFAULT == null ? filePath != null : !FILE_PATH_EDEFAULT.equals(filePath);
+ case ConfigPackage.DYNAMIC_CONFIG__USER_CODE1:
+ return USER_CODE1_EDEFAULT == null ? userCode1 != null : !USER_CODE1_EDEFAULT.equals(userCode1);
+ case ConfigPackage.DYNAMIC_CONFIG__USER_CODE2:
+ return USER_CODE2_EDEFAULT == null ? userCode2 != null : !USER_CODE2_EDEFAULT.equals(userCode2);
case ConfigPackage.DYNAMIC_CONFIG__POLLING:
return polling != POLLING_EDEFAULT;
}
@@ -280,10 +334,12 @@ public class DynamicConfigImpl extends MinimalEObjectImpl.Container implements D
if (eIsProxy()) return super.toString();
StringBuffer result = new StringBuffer(super.toString());
- result.append(" (source: ");
- result.append(source);
- result.append(", filePath: ");
+ result.append(" (filePath: ");
result.append(filePath);
+ result.append(", userCode1: ");
+ result.append(userCode1);
+ result.append(", userCode2: ");
+ result.append(userCode2);
result.append(", polling: ");
result.append(polling);
result.append(')');
@@ -34,44 +35,64 @@ import org.eclipse.etrice.core.config.DynamicConfig;
/**
- * The default value of the '{@link #getFilePath() <em>File Path</em>}' attribute.
+ * The default value of the '{@link #getUserCode1() <em>User Code1</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -34,44 +35,64 @@ import org.eclipse.etrice.core.config.DynamicConfig;
/**
- * The cached value of the '{@link #getFilePath() <em>File Path</em>}' attribute.
+ * The cached value of the '{@link #getUserCode1() <em>User Code1</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->

Back to the top